summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/editfunctionsimpl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/designer/editfunctionsimpl.cpp')
-rw-r--r--kdevdesigner/designer/editfunctionsimpl.cpp42
1 files changed, 21 insertions, 21 deletions
diff --git a/kdevdesigner/designer/editfunctionsimpl.cpp b/kdevdesigner/designer/editfunctionsimpl.cpp
index 44490811..8a91c9f6 100644
--- a/kdevdesigner/designer/editfunctionsimpl.cpp
+++ b/kdevdesigner/designer/editfunctionsimpl.cpp
@@ -1,15 +1,15 @@
/**********************************************************************
** Copyright (C) 2000-2002 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-** information about Qt Commercial License Agreements.
+** information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
@@ -49,15 +49,15 @@
#include <klocale.h>
-EditFunctions::EditFunctions( TQWidget *parent, FormWindow *fw, bool justSlots )
- : EditFunctionsBase( parent, 0, TRUE ), formWindow( fw )
+EditFunctions::EditFunctions( TQWidget *tqparent, FormWindow *fw, bool justSlots )
+ : EditFunctionsBase( tqparent, 0, TRUE ), formWindow( fw )
{
connect( helpButton, TQT_SIGNAL( clicked() ), MainWindow::self, TQT_SLOT( showDialogHelp() ) );
id = 0;
functList.clear();
- TQValueList<MetaDataBase::Function> functionList = MetaDataBase::functionList( fw );
+ TQValueList<MetaDataBase::Function> functionList = MetaDataBase::functionList( TQT_TQOBJECT(fw) );
for ( TQValueList<MetaDataBase::Function>::Iterator it = functionList.begin(); it != functionList.end(); ++it ) {
TQListViewItem *i = new TQListViewItem( functionListView );
@@ -86,7 +86,7 @@ EditFunctions::EditFunctions( TQWidget *parent, FormWindow *fw, bool justSlots )
id++;
if ( (*it).type == "slot" ) {
- if ( MetaDataBase::isSlotUsed( formWindow, MetaDataBase::normalizeFunction( (*it).function ).latin1() ) )
+ if ( MetaDataBase::isSlotUsed( TQT_TQOBJECT(formWindow), MetaDataBase::normalizeFunction( (*it).function ).latin1() ) )
i->setText( 5, i18n( "Yes" ) );
else
i->setText( 5, i18n( "No" ) );
@@ -96,7 +96,7 @@ EditFunctions::EditFunctions( TQWidget *parent, FormWindow *fw, bool justSlots )
}
boxProperties->setEnabled( FALSE );
- functionName->setValidator( new AsciiValidator( TRUE, functionName ) );
+ functionName->setValidator( new AsciiValidator( TRUE, TQT_TQOBJECT(functionName) ) );
if ( functionListView->firstChild() )
functionListView->setCurrentItem( functionListView->firstChild() );
@@ -104,7 +104,7 @@ EditFunctions::EditFunctions( TQWidget *parent, FormWindow *fw, bool justSlots )
showOnlySlots->setChecked( justSlots );
lastType = "function";
- // Enable rename for all QListViewItems
+ // Enable rename for all TQListViewItems
TQListViewItemIterator lvit = functionListView->firstChild();
for ( ; *lvit; lvit++ )
(*lvit)->setRenameEnabled( 0, TRUE );
@@ -116,7 +116,7 @@ EditFunctions::EditFunctions( TQWidget *parent, FormWindow *fw, bool justSlots )
TQT_SLOT( emitItemRenamed(TQListViewItem*, int, const TQString&) ) );
// Connect signal-relay to TQLineEdit "functionName"
- TQObjectList *l = parent->queryList( TQLINEEDIT_OBJECT_NAME_STRING, "functionName" );
+ TQObjectList *l = tqparent->queryList( TQLINEEDIT_OBJECT_NAME_STRING, "functionName" );
TQObject *obj;
TQObjectListIt itemsLineEditIt( *l );
while ( (obj = itemsLineEditIt.current()) != 0 ) {
@@ -131,8 +131,8 @@ EditFunctions::EditFunctions( TQWidget *parent, FormWindow *fw, bool justSlots )
void EditFunctions::okClicked()
{
- TQValueList<MetaDataBase::Function> functionList = MetaDataBase::functionList( formWindow );
- TQString n = i18n( "Add/Remove functions of '%1'" ).arg( formWindow->name() );
+ TQValueList<MetaDataBase::Function> functionList = MetaDataBase::functionList( TQT_TQOBJECT(formWindow) );
+ TQString n = i18n( "Add/Remove functions of '%1'" ).tqarg( formWindow->name() );
TQPtrList<Command> commands;
TQValueList<MetaDataBase::Function>::Iterator fit;
if ( !functionList.isEmpty() ) {
@@ -175,10 +175,10 @@ void EditFunctions::okClicked()
TQString s = function.function;
s = s.simplifyWhiteSpace();
bool startNum = s[ 0 ] >= '0' && s[ 0 ] <= '9';
- bool noParens = s.contains( '(' ) != 1 || s.contains( ')' ) != 1;
- bool illegalSpace = s.find( ' ' ) != -1 && s.find( ' ' ) < s.find( '(' );
+ bool noParens = s.tqcontains( '(' ) != 1 || s.tqcontains( ')' ) != 1;
+ bool illegalSpace = s.tqfind( ' ' ) != -1 && s.tqfind( ' ' ) < s.tqfind( '(' );
- if ( startNum || noParens || illegalSpace || lst.find( function.function ) != -1 ) {
+ if ( startNum || noParens || illegalSpace || lst.tqfind( function.function ) != -1 ) {
invalidFunctions = TRUE;
invalidItems.append( (*it) );
continue;
@@ -291,7 +291,7 @@ void EditFunctions::functionAdd( const TQString &access, const TQString &type )
if ( i->text( 4 ) == "slot" ) {
i->setText( 0, "newSlot()" );
- if ( MetaDataBase::isSlotUsed( formWindow, "newSlot()" ) )
+ if ( MetaDataBase::isSlotUsed( TQT_TQOBJECT(formWindow), "newSlot()" ) )
i->setText( 5, i18n( "Yes" ) );
else
i->setText( 5, i18n( "No" ) );
@@ -398,7 +398,7 @@ void EditFunctions::currentTextChanged( const TQString &txt )
functionListView->currentItem()->setText( 0, txt );
if ( functionListView->currentItem()->text( 4 ) == "slot" ) {
- if ( MetaDataBase::isSlotUsed( formWindow, MetaDataBase::normalizeFunction( txt.latin1() ).latin1() ) )
+ if ( MetaDataBase::isSlotUsed( TQT_TQOBJECT(formWindow), MetaDataBase::normalizeFunction( txt.latin1() ).latin1() ) )
functionListView->currentItem()->setText( 5, i18n( "Yes" ) );
else
functionListView->currentItem()->setText( 5, i18n( "No" ) );
@@ -441,7 +441,7 @@ void EditFunctions::currentTypeChanged( const TQString &type )
lastType = type;
functionListView->currentItem()->setText( 4, type );
if ( type == "slot" ) {
- if ( MetaDataBase::isSlotUsed( formWindow,
+ if ( MetaDataBase::isSlotUsed( TQT_TQOBJECT(formWindow),
MetaDataBase::normalizeFunction( functionListView->currentItem()->text( 0 ).latin1() ).latin1() ) )
functionListView->currentItem()->setText( 5, i18n( "Yes" ) );
else
@@ -454,7 +454,7 @@ void EditFunctions::currentTypeChanged( const TQString &type )
void EditFunctions::changeItem( TQListViewItem *item, Attribute a, const TQString &nV )
{
int itemId;
- TQMap<TQListViewItem*, int>::Iterator fit = functionIds.find( item );
+ TQMap<TQListViewItem*, int>::Iterator fit = functionIds.tqfind( item );
if ( fit != functionIds.end() )
itemId = *fit;
else
@@ -515,7 +515,7 @@ void EditFunctions::displaySlots( bool justSlots )
i->setText( 4, (*it).type );
if ( (*it).type == "slot" ) {
- if ( MetaDataBase::isSlotUsed( formWindow, MetaDataBase::normalizeFunction( (*it).newName ).latin1() ) )
+ if ( MetaDataBase::isSlotUsed( TQT_TQOBJECT(formWindow), MetaDataBase::normalizeFunction( (*it).newName ).latin1() ) )
i->setText( 5, i18n( "Yes" ) );
else
i->setText( 5, i18n( "No" ) );
@@ -1,15 +1,15 @@
** Copyright (C) 2000-2002 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the